==> aws_administrator-2.2.4-py3-none-any.whl: aws_administrator/aws_sso_assign.py <==
#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Assign AWS SSO Permission Sets to multiple accounts."""

from . import helper_aws_sso
from . import helper_common
from . import helper_aws_entrypoint
from .helper_parameters import *
from multithreader import threads
from pprint import pprint as pp


def aws_sso_assign():
    """Assign AWS SSO Permission Sets."""
    # Enter AWS environment.
    session = helper_aws_entrypoint.auth(
        auth_method=auth_method,
        profile_name=profile_name,
        access_key_id=access_key_id,
        secret_access_key=secret_access_key,
        sso_url=sso_url,
        sso_role_name=sso_role_name,
        sso_account_id=sso_account_id
    )
    sso_admin = session.client(
        'sso-admin',
        region_name=region
    )

    # Create accounts list from JSON file.
    data = helper_common.read_json(sso_assign_input_file)
    account_ids = [account['account_id'] for account in data]

    # Execute task with multithreading.
    items = {
        'sso_admin': sso_admin,
        'sso_instance_arn': sso_instance_arn,
        'data': data
    }
    results = threads(
        helper_aws_sso.assign_permission_sets_dry_run,
        account_ids,
        items,
        thread_num=THREAD_NUM
    ) if DRY_RUN else threads(
        helper_aws_sso.assign_permission_sets,
        account_ids,
        items,
        thread_num=THREAD_NUM
    )

    # Print results.
    pp(results)


def main():
    """Execute main function."""
    aws_sso_assign()


if __name__ == '__main__':
    main()

==> aws_administrator-2.3.4-py3-none-any.whl: aws_administrator/aws_sso_assign.py <==
#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Assign AWS SSO Permission Sets to multiple accounts."""

from . import helper_aws_sso
from . import helper_common
from . import helper_aws_entrypoint
from .helper_parameters import *  # NOQA
from multithreader import threads
from pprint import pprint as pp


def aws_sso_assign():
    """Assign AWS SSO Permission Sets."""
    # Enter AWS environment.
    session = helper_aws_entrypoint.auth(
        auth_method=auth_method,
        profile_name=profile_name,
        access_key_id=access_key_id,
        secret_access_key=secret_access_key,
        sso_url=sso_url,
        sso_role_name=sso_role_name,
        sso_account_id=sso_account_id
    )
    sso_admin = session.client(
        'sso-admin',
        region_name=region
    )

    # Create accounts list from JSON file.
    data = helper_common.read_json(sso_assign_input_file)
    account_ids = [account['account_id'] for account in data]

    # Execute task with multithreading.
    items = {
        'sso_admin': sso_admin,
        'sso_instance_arn': sso_instance_arn,
        'data': data
    }
    results = threads(
        helper_aws_sso.assign_permission_sets_dry_run,
        account_ids,
        items,
        thread_num=THREAD_NUM
    ) if DRY_RUN else threads(
        helper_aws_sso.assign_permission_sets,
        account_ids,
        items,
        thread_num=THREAD_NUM
    )

    # Print results.
    pp(results)


def main():
    """Execute main function."""
    aws_sso_assign()


if __name__ == '__main__':
    main()
